nxp-pac

Crates

git

Versions

mcxn947_cm33_core0

Flavors

Caplength

Struct Caplength 

#[repr(transparent)]
pub struct Caplength(pub u8);
Capability Registers Length

Tuple Fields

0: u8

Implementations

Source

impl Caplength

pub const fn caplength(&self) -> u8

These bits are used as an offset to add to register base to find the beginning of the Operational Register. Default value is ‘40h’.

pub const fn set_caplength(&mut self, val: u8)

These bits are used as an offset to add to register base to find the beginning of the Operational Register. Default value is ‘40h’.