Struct Usbcmd
Source #[repr(transparent)]
pub struct Usbcmd(pub u32);
Asynchronous Schedule Enable
Asynchronous Schedule Enable
Interrupt on Async Advance Doorbell
Interrupt on Async Advance Doorbell
Asynchronous Schedule Park Mode Count
Asynchronous Schedule Park Mode Count
Asynchronous Schedule Park Mode Enable
Asynchronous Schedule Park Mode Enable
Setup TripWire [device mode only]
Setup TripWire [device mode only]
Add dTD TripWire[device mode only]
Add dTD TripWire[device mode only]
Frame List Size [host mode only]
Frame List Size [host mode only]
Interrupt Threshold Control
Interrupt Threshold Control
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.