Struct Usbintr
Source #[repr(transparent)]
pub struct Usbintr(pub u32);
USB Error Interrupt Enable
USB Error Interrupt Enable
Port Change Detect Interrupt Enable
Port Change Detect Interrupt Enable
Frame List Rollover Interrupt Enable
Frame List Rollover Interrupt Enable
System Error Interrupt Enable
System Error Interrupt Enable
Async Advance Interrupt Enable
Async Advance Interrupt Enable
USB Reset Interrupt Enable
USB Reset Interrupt Enable
SOF Received Interrupt Enable
SOF Received Interrupt Enable
USB Host Asynchronous Interrupt Enable
USB Host Asynchronous Interrupt Enable
USB Host Periodic Interrupt Enable
USB Host Periodic Interrupt Enable
General Purpose Timer #0 Interrupt Enable
General Purpose Timer #0 Interrupt Enable
General Purpose Timer #1 Interrupt Enable
General Purpose Timer #1 Interrupt Enable
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.